@@ -35,17 +35,34 @@ static int		pf_batch_fsbs;
 
 static void		pf_read_inode_dirs(prefetch_args_t *, xfs_buf_t *);
 
-/* buffer priorities for the libxfs cache */
+/*
+ * Buffer priorities for the libxfs cache
+ *
+ * Directory metadata is ranked higher than other metadata as it's used
+ * in phases 3, 4 and 6, while other metadata is only used in 3 & 4.
+ */
 
-#define B_DIR_BMAP	15
-#define B_DIR_META_2	14	/* metadata in secondary queue */
-#define B_DIR_META_H	13	/* metadata fetched for PF_META_ONLY */
-#define B_DIR_META_S	12	/* single block of metadata */
-#define B_DIR_META	11
-#define B_DIR_INODE	10
-#define B_BMAP		9
-#define B_INODE		8
+/* intermediate directory btree nodes - can't be queued */
+#define B_DIR_BMAP	CACHE_PREFETCH_PRIORITY + 7
+/* directory metadata in secondary queue */
+#define B_DIR_META_2	CACHE_PREFETCH_PRIORITY + 6
+/* dir metadata that had to fetched from the primary queue to avoid stalling */
+#define B_DIR_META_H	CACHE_PREFETCH_PRIORITY + 5
+/* single block of directory metadata (can't batch read) */
+#define B_DIR_META_S	CACHE_PREFETCH_PRIORITY + 4
+/* dir metadata with more than one block fetched in a single I/O */
+#define B_DIR_META	CACHE_PREFETCH_PRIORITY + 3
+/* inode clusters with directory inodes */
+#define B_DIR_INODE	CACHE_PREFETCH_PRIORITY + 2
+/* intermediate extent btree nodes */
+#define B_BMAP		CACHE_PREFETCH_PRIORITY + 1
+/* inode clusters without any directory entries */
+#define B_INODE		CACHE_PREFETCH_PRIORITY
 
+/*
+ * Test if bit 0 or 2 is set in the "priority tag" of the buffer to see if
+ * the buffer is for an inode or other metadata.
+ */
 #define B_IS_INODE(f)	(((f) & 5) == 0)
 #define B_IS_META(f)	(((f) & 5) != 0)
 
@@ -152,38 +169,39 @@ pf_read_bmbt_reclist(
 	int			numrecs)
 {
 	int			i;
-	xfs_dfsbno_t		s;		/* start */
-	xfs_dfilblks_t		c;		/* count */
-	xfs_dfiloff_t		o;		/* offset */
+	xfs_bmbt_irec_t		irec;
 	xfs_dfilblks_t		cp = 0;		/* prev count */
 	xfs_dfiloff_t		op = 0;		/* prev offset */
-	int			flag;		/* extent flag */
 
 	for (i = 0; i < numrecs; i++, rp++) {
-		convert_extent((xfs_bmbt_rec_32_t*)rp, &o, &s, &c, &flag);
+		libxfs_bmbt_disk_get_all(rp, &irec);
 
-		if (((i > 0) && (op + cp > o)) || (c == 0) ||
-				(o >= fs_max_file_offset))
+		if (((i > 0) && (op + cp > irec.br_startoff)) ||
+				(irec.br_blockcount == 0) ||
+				(irec.br_startoff >= fs_max_file_offset))
 			return 0;
 
-		if (!verify_dfsbno(mp, s) || !verify_dfsbno(mp, s + c - 1))
+		if (!verify_dfsbno(mp, irec.br_startblock) || !verify_dfsbno(mp,
+				irec.br_startblock + irec.br_blockcount - 1))
 			return 0;
 
-		if (!args->dirs_only && ((o + c) >= mp->m_dirfreeblk))
+		if (!args->dirs_only && ((irec.br_startoff +
+				irec.br_blockcount) >= mp->m_dirfreeblk))
 			break;	/* only Phase 6 reads the free blocks */
 
-		op = o;
-		cp = c;
+		op = irec.br_startoff;
+		cp = irec.br_blockcount;
 
-		while (c) {
+		while (irec.br_blockcount) {
 			unsigned int	len;
 #ifdef XR_PF_TRACE
 			pftrace("queuing dir extent in AG %d", args->agno);
 #endif
-			len = (c > mp->m_dirblkfsbs) ? mp->m_dirblkfsbs : c;
-			pf_queue_io(args, s, len, B_DIR_META);
-			c -= len;
-			s += len;
+			len = (irec.br_blockcount > mp->m_dirblkfsbs) ?
+					mp->m_dirblkfsbs : irec.br_blockcount;
+			pf_queue_io(args, irec.br_startblock, len, B_DIR_META);
+			irec.br_blockcount -= len;
+			irec.br_startblock += len;
 		}
 	}
 	return 1;
@@ -600,7 +618,6 @@ pf_queuing_worker(
 	ino_tree_node_t		*irec;
 	ino_tree_node_t		*cur_irec;
 	int			blks_per_cluster;
-	int			inos_per_cluster;
 	xfs_agblock_t		bno;
 	int			i;
 	int			err;
@@ -608,7 +625,6 @@ pf_queuing_worker(
 	blks_per_cluster =  XFS_INODE_CLUSTER_SIZE(mp) >> mp->m_sb.sb_blocklog;
 	if (blks_per_cluster == 0)
 		blks_per_cluster = 1;
-	inos_per_cluster = blks_per_cluster * mp->m_sb.sb_inopblock;
 
 	for (i = 0; i < PF_THREAD_COUNT; i++) {
 		err = pthread_create(&args->io_threads[i], NULL,
@@ -661,7 +677,7 @@ pf_queuing_worker(
 					(cur_irec->ino_isa_dir != 0) ?
 						B_DIR_INODE : B_INODE);
 			bno += blks_per_cluster;
-			num_inos += inos_per_cluster;
+			num_inos += inodes_per_cluster;
 		} while (num_inos < XFS_IALLOC_INODES(mp));
 	}
 
@@ -738,6 +754,7 @@ start_inode_prefetch(
 	prefetch_args_t		*prev_args)
 {
 	prefetch_args_t		*args;
+	long			max_queue;
 
 	if (!do_prefetch || agno >= mp->m_sb.sb_agcount)
 		return NULL;
@@ -757,8 +774,12 @@ start_inode_prefetch(
 	 * and not any other associated metadata like directories
 	 */
 
-	sem_init(&args->ra_count, 0, libxfs_bcache->c_maxcount / thread_count /
-		(XFS_IALLOC_BLOCKS(mp) / (XFS_INODE_CLUSTER_SIZE(mp) >> mp->m_sb.sb_blocklog)) / 8);
+	max_queue = libxfs_bcache->c_maxcount / thread_count / 8;
+	if (XFS_INODE_CLUSTER_SIZE(mp) > mp->m_sb.sb_blocksize)
+		max_queue = max_queue * (XFS_INODE_CLUSTER_SIZE(mp) >>
+				mp->m_sb.sb_blocklog) / XFS_IALLOC_BLOCKS(mp);
+
+	sem_init(&args->ra_count, 0, max_queue);
 
 	if (!prev_args) {
 		if (!pf_create_prefetch_thread(args))
